==> jc-1.4.0.tar.gz: soot/baf/internal/BIfNeInst.h <==
// public class soot.baf.internal.BIfNeInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class a767e8b6884c32dc soot_baf_internal_BIfNeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractBranchInst

#include "soot/baf/internal/AbstractBranchInst.h"

#ifndef _JC_soot_baf_internal_BIfNeInst_H_
#define _JC_soot_baf_internal_BIfNeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BIfNeInst$sub_refs	_jc_soot_baf_internal_BIfNeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BIfNeInst$sub_nonrefs	_jc_soot_baf_internal_BIfNeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BIfNeInst$refs	_jc_soot_baf_internal_BIfNeInst$refs;
typedef struct _jc_soot_baf_internal_BIfNeInst$nonrefs	_jc_soot_baf_internal_BIfNeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BIfNeInst$object	_jc_soot_baf_internal_BIfNeInst$object;

typedef const struct _jc_soot_baf_internal_BIfNeInst$vmethods	_jc_soot_baf_internal_BIfNeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BIfNeInst$vtable	_jc_soot_baf_internal_BIfNeInst$vtable;
typedef const struct _jc_soot_baf_internal_BIfNeInst$vtype	_jc_soot_baf_internal_BIfNeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BIfNeInst$method$_init$9fbfbaac54ec3a82(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_baf_internal_BIfNeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BIfNeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
extern jint _jc_soot_baf_internal_BIfNeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
extern jint _jc_soot_baf_internal_BIfNeInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BIfNeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
extern jint _jc_soot_baf_internal_BIfNeInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
extern jint _jc_soot_baf_internal_BIfNeInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BIfNeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BIfNeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
	_jc_soot_baf_internal_BIfNeInst$vmethods	soot_baf_internal_BIfNeInst;
};

// Vtype
struct _jc_soot_baf_internal_BIfNeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BIfNeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BIfNeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BIfNeInst$refs {
    _jc_soot_baf_internal_BIfNeInst$sub_refs	soot_baf_internal_BIfNeInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BIfNeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BIfNeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_BIfNeInst$sub_nonrefs	soot_baf_internal_BIfNeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BIfNeInst$object {
	_jc_soot_baf_internal_BIfNeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BIfNeInst$vtype	*vtype;
	_jc_soot_baf_internal_BIfNeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BIfNeInst$vtype _jc_soot_baf_internal_BIfNeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BIfNeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BIfNeInst$class_object;

#endif	/* _JC_soot_baf_internal_BIfNeInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BIfNeInst.h <==
// public class soot.baf.internal.BIfNeInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class a767e8b6884c32dc soot_baf_internal_BIfNeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractBranchInst

#include "soot/baf/internal/AbstractBranchInst.h"

#ifndef _JC_soot_baf_internal_BIfNeInst_H_
#define _JC_soot_baf_internal_BIfNeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BIfNeInst$sub_refs	_jc_soot_baf_internal_BIfNeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BIfNeInst$sub_nonrefs	_jc_soot_baf_internal_BIfNeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BIfNeInst$refs	_jc_soot_baf_internal_BIfNeInst$refs;
typedef struct _jc_soot_baf_internal_BIfNeInst$nonrefs	_jc_soot_baf_internal_BIfNeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BIfNeInst$object	_jc_soot_baf_internal_BIfNeInst$object;

typedef const struct _jc_soot_baf_internal_BIfNeInst$vmethods	_jc_soot_baf_internal_BIfNeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BIfNeInst$vtable	_jc_soot_baf_internal_BIfNeInst$vtable;
typedef const struct _jc_soot_baf_internal_BIfNeInst$vtype	_jc_soot_baf_internal_BIfNeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BIfNeInst$method$_init$9fbfbaac54ec3a82(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BIfNeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BIfNeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BIfNeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BIfNeInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BIfNeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BIfNeInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BIfNeInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BIfNeInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BIfNeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BIfNeInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BIfNeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
	_jc_soot_baf_internal_BIfNeInst$vmethods	soot_baf_internal_BIfNeInst;
};

// Vtype
struct _jc_soot_baf_internal_BIfNeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BIfNeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BIfNeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BIfNeInst$refs {
    _jc_soot_baf_internal_BIfNeInst$sub_refs	soot_baf_internal_BIfNeInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BIfNeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BIfNeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_BIfNeInst$sub_nonrefs	soot_baf_internal_BIfNeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BIfNeInst$object {
	_jc_soot_baf_internal_BIfNeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BIfNeInst$vtype	*vtype;
	_jc_soot_baf_internal_BIfNeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BIfNeInst$vtype _jc_soot_baf_internal_BIfNeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BIfNeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BIfNeInst$class_object;

#endif	/* _JC_soot_baf_internal_BIfNeInst_H_ */
